@@ -5,12 +5,12 @@
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
 
+from abc import ABCMeta, abstractmethod
 from functools import total_ordering
 
-from abc import ABCMeta, abstractmethod
-
 from nltk.internals import raise_unorderable_types
 
+
 @total_ordering
 class AbstractCCGCategory(metaclass=ABCMeta):
     """
@@ -131,7 +131,7 @@ class CCGVar(AbstractCCGCategory):
         return self
 
     def can_unify(self, other):
-        """ If the variable can be replaced with other
+        """If the variable can be replaced with other
         a substitution is returned.
         """
         if other.is_primitive() or not self._prim_only:
@@ -146,7 +146,7 @@ class CCGVar(AbstractCCGCategory):
 
 
 @total_ordering
-class Direction(object):
+class Direction:
     """
     Class representing the direction of a function application.
     Also contains maintains information as to which combinators
@@ -237,7 +237,7 @@ class Direction(object):
         r_str = ""
         for r in self._restrs:
             r_str = r_str + "%s" % r
-        return "%s%s" % (self._dir, r_str)
+        return f"{self._dir}{r_str}"
 
     # The negation operator reverses the direction of the application
     def __neg__(self):
@@ -297,7 +297,7 @@ class PrimitiveCategory(AbstractCCGCategory):
         if self._restrs == []:
             return "%s" % self._categ
         restrictions = "[%s]" % ",".join(repr(r) for r in self._restrs)
-        return "%s%s" % (self._categ, restrictions)
+        return f"{self._categ}{restrictions}"
 
 
 class FunctionalCategory(AbstractCCGCategory):
@@ -355,4 +355,4 @@ class FunctionalCategory(AbstractCCGCategory):
         return self._dir
 
     def __str__(self):
-        return "(%s%s%s)" % (self._res, self._dir, self._arg)
+        return f"({self._res}{self._dir}{self._arg})"
