@@ -17,12 +17,12 @@ TO DO: better Named Entity classification
 TO DO: add lemmatization
 """
 
-from nltk.tokenize import RegexpTokenizer
-from nltk.classify.util import accuracy, check_megam_config
 from nltk.classify.maxent import MaxentClassifier
+from nltk.classify.util import accuracy, check_megam_config
+from nltk.tokenize import RegexpTokenizer
 
 
-class RTEFeatureExtractor(object):
+class RTEFeatureExtractor:
     """
     This builds a bag of words for both the text and the hypothesis after
     throwing away some stopwords, then calculates overlap and difference.
@@ -35,27 +35,25 @@ class RTEFeatureExtractor(object):
         :type stop: bool
         """
         self.stop = stop
-        self.stopwords = set(
-            [
-                "a",
-                "the",
-                "it",
-                "they",
-                "of",
-                "in",
-                "to",
-                "is",
-                "have",
-                "are",
-                "were",
-                "and",
-                "very",
-                ".",
-                ",",
-            ]
-        )
+        self.stopwords = {
+            "a",
+            "the",
+            "it",
+            "they",
+            "of",
+            "in",
+            "to",
+            "is",
+            "have",
+            "are",
+            "were",
+            "and",
+            "very",
+            ".",
+            ",",
+        }
 
-        self.negwords = set(["no", "not", "never", "failed", "rejected", "denied"])
+        self.negwords = {"no", "not", "never", "failed", "rejected", "denied"}
         # Try to tokenize so that abbreviations, monetary amounts, email
         # addresses, URLs are single tokens.
         tokenizer = RegexpTokenizer(r"[\w.@:/]+|\w+|\$[\d.]+")
@@ -67,8 +65,8 @@ class RTEFeatureExtractor(object):
         self.hyp_words = set(self.hyp_tokens)
 
         if use_lemmatize:
-            self.text_words = set(self._lemmatize(token) for token in self.text_tokens)
-            self.hyp_words = set(self._lemmatize(token) for token in self.hyp_tokens)
+            self.text_words = {self._lemmatize(token) for token in self.text_tokens}
+            self.hyp_words = {self._lemmatize(token) for token in self.hyp_tokens}
 
         if self.stop:
             self.text_words = self.text_words - self.stopwords
@@ -85,7 +83,7 @@ class RTEFeatureExtractor(object):
         :param toktype: distinguish Named Entities from ordinary words
         :type toktype: 'ne' or 'word'
         """
-        ne_overlap = set(token for token in self._overlap if self._ne(token))
+        ne_overlap = {token for token in self._overlap if self._ne(token)}
         if toktype == "ne":
             if debug:
                 print("ne overlap", ne_overlap)
@@ -104,7 +102,7 @@ class RTEFeatureExtractor(object):
         :param toktype: distinguish Named Entities from ordinary words
         :type toktype: 'ne' or 'word'
         """
-        ne_extra = set(token for token in self._hyp_extra if self._ne(token))
+        ne_extra = {token for token in self._hyp_extra if self._ne(token)}
         if toktype == "ne":
             return ne_extra
         elif toktype == "word":
