@@ -32,8 +32,8 @@ In order to provide globally unique IDs for each pair, a new attribute
 file, taking values 1, 2 or 3. The GID is formatted 'm-n', where 'm' is the
 challenge number and 'n' is the pair ID.
 """
-from nltk.corpus.reader.util import *
 from nltk.corpus.reader.api import *
+from nltk.corpus.reader.util import *
 from nltk.corpus.reader.xmldocs import *
 
 
@@ -51,7 +51,7 @@ def norm(value_string):
     return valdict[value_string.upper()]
 
 
-class RTEPair(object):
+class RTEPair:
     """
     Container for RTE text-hypothesis pairs.
 
@@ -82,7 +82,7 @@ class RTEPair(object):
         """
         self.challenge = challenge
         self.id = pair.attrib["id"]
-        self.gid = "%s-%s" % (self.challenge, self.id)
+        self.gid = f"{self.challenge}-{self.id}"
         self.text = pair[0].text
         self.hyp = pair[1].text
 
@@ -103,7 +103,7 @@ class RTEPair(object):
 
     def __repr__(self):
         if self.challenge:
-            return "<RTEPair: gid=%s-%s>" % (self.challenge, self.id)
+            return f"<RTEPair: gid={self.challenge}-{self.id}>"
         else:
             return "<RTEPair: id=%s>" % self.id
 
