@@ -14,11 +14,11 @@ The input is assumed to be in Malt-TAB format
 (http://stp.lingfil.uu.se/~nivre/research/MaltXML.html).
 """
 
+import subprocess
+import warnings
 from collections import defaultdict
 from itertools import chain
 from pprint import pformat
-import subprocess
-import warnings
 
 from nltk.tree import Tree
 
@@ -27,7 +27,7 @@ from nltk.tree import Tree
 #################################################################
 
 
-class DependencyGraph(object):
+class DependencyGraph:
     """
     A container for the nodes and labelled edges of a dependency structure.
     """
@@ -169,7 +169,7 @@ class DependencyGraph(object):
 
         # Draw the remaining nodes
         for node in sorted(self.nodes.values(), key=lambda v: v["address"]):
-            s += '\n%s [label="%s (%s)"]' % (
+            s += '\n{} [label="{} ({})"]'.format(
                 node["address"],
                 node["address"],
                 node["word"],
@@ -177,9 +177,9 @@ class DependencyGraph(object):
             for rel, deps in node["deps"].items():
                 for dep in deps:
                     if rel is not None:
-                        s += '\n%s -> %s [label="%s"]' % (node["address"], dep, rel)
+                        s += '\n{} -> {} [label="{}"]'.format(node["address"], dep, rel)
                     else:
-                        s += "\n%s -> %s " % (node["address"], dep)
+                        s += "\n{} -> {} ".format(node["address"], dep)
         s += "\n}"
 
         return s
@@ -197,30 +197,13 @@ class DependencyGraph(object):
 
         """
         dot_string = self.to_dot()
-
-        try:
-            process = subprocess.Popen(
-                ["dot", "-Tsvg"],
-                stdin=subprocess.PIPE,
-                stdout=subprocess.PIPE,
-                stderr=subprocess.PIPE,
-                universal_newlines=True,
-            )
-        except OSError as e:
-            raise Exception("Cannot find the dot binary from Graphviz package") from e
-        out, err = process.communicate(dot_string)
-        if err:
-            raise Exception(
-                "Cannot create svg representation by running dot from string: {}"
-                "".format(dot_string)
-            )
-        return out
+        return dot2img(dot_string)
 
     def __str__(self):
         return pformat(self.nodes)
 
     def __repr__(self):
-        return "<DependencyGraph with {0} nodes>".format(len(self.nodes))
+        return f"<DependencyGraph with {len(self.nodes)} nodes>"
 
     @staticmethod
     def load(
@@ -345,7 +328,7 @@ class DependencyGraph(object):
                     cell_extractor = extractors[cell_number]
                 except KeyError as e:
                     raise ValueError(
-                        "Number of tab-delimited fields ({0}) not supported by "
+                        "Number of tab-delimited fields ({}) not supported by "
                         "CoNLL(10) or Malt-Tab(4) format".format(cell_number)
                     ) from e
 
@@ -401,7 +384,7 @@ class DependencyGraph(object):
         return w
 
     def _tree(self, i):
-        """ Turn dependency graphs into NLTK trees.
+        """Turn dependency graphs into NLTK trees.
 
         :param int i: index of a node
         :return: either a word (if the indexed node is a leaf) or a ``Tree``.
@@ -439,8 +422,7 @@ class DependencyGraph(object):
         for i in sorted(chain.from_iterable(node["deps"].values())):
             dep = self.get_by_address(i)
             yield (head, dep["rel"], (dep["word"], dep["ctag"]))
-            for triple in self.triples(node=dep):
-                yield triple
+            yield from self.triples(node=dep)
 
     def _hd(self, i):
         try:
@@ -535,7 +517,7 @@ class DependencyGraph(object):
             )
         else:
             raise ValueError(
-                "Number of tab-delimited fields ({0}) not supported by "
+                "Number of tab-delimited fields ({}) not supported by "
                 "CoNLL(10) or Malt-Tab(4) format".format(style)
             )
 
@@ -564,6 +546,37 @@ class DependencyGraph(object):
         return g
 
 
+def dot2img(dot_string, t="svg"):
+    """
+    Create image representation fom dot_string, using the 'dot' program
+    from the Graphviz package.
+
+    Use the 't' argument to specify the image file format, for ex.
+    'png' or 'jpeg' (Running 'dot -T:' lists all available formats).
+
+    sys.stdout is used instead of subprocess.PIPE, to avoid decoding errors
+    """
+    from sys import stderr, stdout
+
+    try:
+        proc = subprocess.run(
+            ["dot", "-T%s" % t],
+            input=dot_string,
+            stdout=stdout,
+            stderr=stderr,
+            text=True,
+        )
+    except OSError as e:
+        raise Exception("Cannot find the dot binary from Graphviz package") from e
+    out, err = proc.stdout, proc.stderr
+    if err:
+        raise Exception(
+            "Cannot create image representation by running dot from string: {}"
+            "".format(dot_string)
+        )
+    return out
+
+
 class DependencyGraphError(Exception):
     """Dependency graph exception."""
 
