@@ -1,11 +1,11 @@
-# -*- coding: utf-8 -*-
 # Natural Language Toolkit: Text Trees
 #
-# Copyright (C) 2001-2020 NLTK Project
+# Copyright (C) 2001-2021 NLTK Project
 # Author: Edward Loper <edloper@gmail.com>
 #         Steven Bird <stevenbird1@gmail.com>
 #         Peter Ljunglöf <peter.ljunglof@gu.se>
 #         Nathan Bodenstab <bodenstab@cslu.ogi.edu> (tree transforms)
+#         Eric Kafe <kafe.eric@gmail.com> (Tree.fromlist())
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
 
@@ -18,11 +18,10 @@ import re
 import sys
 from abc import ABCMeta, abstractmethod
 
-
-from nltk.grammar import Production, Nonterminal
+from nltk.grammar import Nonterminal, Production
+from nltk.internals import raise_unorderable_types
 from nltk.probability import ProbabilisticMixIn
 from nltk.util import slice_bounds
-from nltk.internals import raise_unorderable_types
 
 # TODO: add LabelledTree (can be used for dependency trees)
 
@@ -31,9 +30,8 @@ from nltk.internals import raise_unorderable_types
 ######################################################################
 
 
-
 class Tree(list):
-    """
+    r"""
     A Tree represents a hierarchical grouping of leaves and subtrees.
     For example, each constituent in a syntax tree is represented by a single Tree.
 
@@ -355,8 +353,7 @@ class Tree(list):
             yield self
         for child in self:
             if isinstance(child, Tree):
-                for subtree in child.subtrees(filter):
-                    yield subtree
+                yield from child.subtrees(filter)
 
     def productions(self):
         """
@@ -502,7 +499,7 @@ class Tree(list):
         :type  expandUnary: bool
         :param childChar: A string separating the head node from its children in an artificial node (default = "|")
         :type  childChar: str
-        :param parentChar: A sting separating the node label from its parent annotation (default = "^")
+        :param parentChar: A string separating the node label from its parent annotation (default = "^")
         :type  parentChar: str
         :param unaryChar: A string joining two non-terminals in a unary production (default = "+")
         :type  unaryChar: str
@@ -647,17 +644,17 @@ class Tree(list):
         """
         if not isinstance(brackets, str) or len(brackets) != 2:
             raise TypeError("brackets must be a length-2 string")
-        if re.search("\s", brackets):
+        if re.search(r"\s", brackets):
             raise TypeError("whitespace brackets not allowed")
         # Construct a regexp that will tokenize the string.
         open_b, close_b = brackets
         open_pattern, close_pattern = (re.escape(open_b), re.escape(close_b))
         if node_pattern is None:
-            node_pattern = "[^\s%s%s]+" % (open_pattern, close_pattern)
+            node_pattern = fr"[^\s{open_pattern}{close_pattern}]+"
         if leaf_pattern is None:
-            leaf_pattern = "[^\s%s%s]+" % (open_pattern, close_pattern)
+            leaf_pattern = fr"[^\s{open_pattern}{close_pattern}]+"
         token_re = re.compile(
-            "%s\s*(%s)?|%s|(%s)"
+            r"%s\s*(%s)?|%s|(%s)"
             % (open_pattern, node_pattern, close_pattern, leaf_pattern)
         )
         # Walk through each token, updating a stack of trees.
@@ -734,9 +731,27 @@ class Tree(list):
         if pos > 10:
             s = "..." + s[pos - 10 :]
             offset = 13
-        msg += '\n%s"%s"\n%s^' % (" " * 16, s, " " * (17 + offset))
+        msg += '\n{}"{}"\n{}^'.format(" " * 16, s, " " * (17 + offset))
         raise ValueError(msg)
 
+    @classmethod
+    def fromlist(cls, l):
+        """
+        :type l: list
+        :param l: a tree represented as nested lists
+
+        :return: A tree corresponding to the list representation ``l``.
+        :rtype: Tree
+
+        Convert nested lists to a NLTK Tree
+        """
+        if type(l) == list and len(l) > 0:
+            label = repr(l[0])
+            if len(l) > 1:
+                return Tree(label, [cls.fromlist(child) for child in l[1:]])
+            else:
+                return label
+
     # ////////////////////////////////////////////////////////////
     # Visualization & String Representation
     # ////////////////////////////////////////////////////////////
@@ -761,7 +776,7 @@ class Tree(list):
 
     def __repr__(self):
         childstr = ", ".join(repr(c) for c in self)
-        return "%s(%s, [%s])" % (
+        return "{}({}, [{}])".format(
             type(self).__name__,
             repr(self._label),
             childstr,
@@ -773,10 +788,11 @@ class Tree(list):
         PNG is used instead of PDF, since it can be displayed in the qt console and
         has wider browser support.
         """
-        import os
         import base64
+        import os
         import subprocess
         import tempfile
+
         from nltk.draw.tree import tree_to_treesegment
         from nltk.draw.util import CanvasFrame
         from nltk.internals import find_binary
@@ -788,8 +804,8 @@ class Tree(list):
         # print_to_file uses scrollregion to set the width and height of the pdf.
         _canvas_frame.canvas()["scrollregion"] = (0, 0, w, h)
         with tempfile.NamedTemporaryFile() as file:
-            in_path = "{0:}.ps".format(file.name)
-            out_path = "{0:}.png".format(file.name)
+            in_path = f"{file.name}.ps"
+            out_path = f"{file.name}.png"
             _canvas_frame.print_to_file(in_path)
             _canvas_frame.destroy_widget(widget)
             try:
@@ -802,11 +818,11 @@ class Tree(list):
                             verbose=False,
                         )
                     ]
-                    + "-q -dEPSCrop -sDEVICE=png16m -r90 -dTextAlphaBits=4 -dGraphicsAlphaBits=4 -dSAFER -dBATCH -dNOPAUSE -sOutputFile={0:} {1:}".format(
+                    + "-q -dEPSCrop -sDEVICE=png16m -r90 -dTextAlphaBits=4 -dGraphicsAlphaBits=4 -dSAFER -dBATCH -dNOPAUSE -sOutputFile={} {}".format(
                         out_path, in_path
                     ).split()
                 )
-            except LookupError:
+            except LookupError as e:
                 pre_error_message = str(
                     "The Ghostscript executable isn't found.\n"
                     "See http://web.mit.edu/ghostscript/www/Install.htm\n"
@@ -814,7 +830,7 @@ class Tree(list):
                     "https://docs.brew.sh/Installation then `brew install ghostscript`"
                 )
                 print(pre_error_message, file=sys.stderr)
-                raise LookupError
+                raise LookupError from e
 
             with open(out_path, "rb") as sr:
                 res = sr.read()
@@ -859,9 +875,9 @@ class Tree(list):
 
         # If it doesn't fit on one line, then write it on multi-lines.
         if isinstance(self._label, str):
-            s = "%s%s%s" % (parens[0], self._label, nodesep)
+            s = f"{parens[0]}{self._label}{nodesep}"
         else:
-            s = "%s%s%s" % (parens[0], repr(self._label), nodesep)
+            s = f"{parens[0]}{repr(self._label)}{nodesep}"
         for child in self:
             if isinstance(child, Tree):
                 s += (
@@ -895,7 +911,7 @@ class Tree(list):
         :return: A latex qtree representation of this tree.
         :rtype: str
         """
-        reserved_chars = re.compile("([#\$%&~_\{\}])")
+        reserved_chars = re.compile(r"([#\$%&~_\{\}])")
 
         pformat = self.pformat(indent=6, nodesep="", parens=("[.", " ]"))
         return r"\Tree " + re.sub(reserved_chars, r"\\\1", pformat)
@@ -912,7 +928,7 @@ class Tree(list):
             else:
                 childstrs.append(repr(child))
         if isinstance(self._label, str):
-            return "%s%s%s %s%s" % (
+            return "{}{}{} {}{}".format(
                 parens[0],
                 self._label,
                 nodesep,
@@ -920,7 +936,7 @@ class Tree(list):
                 parens[1],
             )
         else:
-            return "%s%s%s %s%s" % (
+            return "{}{}{} {}{}".format(
                 parens[0],
                 repr(self._label),
                 nodesep,
@@ -931,15 +947,15 @@ class Tree(list):
 
 class ImmutableTree(Tree):
     def __init__(self, node, children=None):
-        super(ImmutableTree, self).__init__(node, children)
+        super().__init__(node, children)
         # Precompute our hash value.  This ensures that we're really
         # immutable.  It also means we only have to calculate it once.
         try:
             self._hash = hash((self._label, tuple(self)))
-        except (TypeError, ValueError):
+        except (TypeError, ValueError) as e:
             raise ValueError(
                 "%s: node value and children " "must be immutable" % type(self).__name__
-            )
+            ) from e
 
     def __setitem__(self, index, value):
         raise ValueError("%s may not be modified" % type(self).__name__)
@@ -1019,7 +1035,7 @@ class AbstractParentedTree(Tree, metaclass=ABCMeta):
     """
 
     def __init__(self, node, children=None):
-        super(AbstractParentedTree, self).__init__(node, children)
+        super().__init__(node, children)
         # If children is None, the tree is read from node, and
         # all parents will be set during parsing.
         if children is not None:
@@ -1087,7 +1103,7 @@ class AbstractParentedTree(Tree, metaclass=ABCMeta):
                 if isinstance(self[i], Tree):
                     self._delparent(self[i], i)
             # Delete the children from our child list.
-            super(AbstractParentedTree, self).__delitem__(index)
+            super().__delitem__(index)
 
         # del ptree[i]
         elif isinstance(index, int):
@@ -1099,7 +1115,7 @@ class AbstractParentedTree(Tree, metaclass=ABCMeta):
             if isinstance(self[index], Tree):
                 self._delparent(self[index], index)
             # Remove the child from our child list.
-            super(AbstractParentedTree, self).__delitem__(index)
+            super().__delitem__(index)
 
         elif isinstance(index, (list, tuple)):
             # del ptree[()]
@@ -1141,7 +1157,7 @@ class AbstractParentedTree(Tree, metaclass=ABCMeta):
                 if isinstance(child, Tree):
                     self._setparent(child, start + i * step)
             # finally, update the content of the child list itself.
-            super(AbstractParentedTree, self).__setitem__(index, value)
+            super().__setitem__(index, value)
 
         # ptree[i] = value
         elif isinstance(index, int):
@@ -1159,7 +1175,7 @@ class AbstractParentedTree(Tree, metaclass=ABCMeta):
             if isinstance(self[index], Tree):
                 self._delparent(self[index], index)
             # Update our child list.
-            super(AbstractParentedTree, self).__setitem__(index, value)
+            super().__setitem__(index, value)
 
         elif isinstance(index, (list, tuple)):
             # ptree[()] = value
@@ -1181,13 +1197,13 @@ class AbstractParentedTree(Tree, metaclass=ABCMeta):
     def append(self, child):
         if isinstance(child, Tree):
             self._setparent(child, len(self))
-        super(AbstractParentedTree, self).append(child)
+        super().append(child)
 
     def extend(self, children):
         for child in children:
             if isinstance(child, Tree):
                 self._setparent(child, len(self))
-            super(AbstractParentedTree, self).append(child)
+            super().append(child)
 
     def insert(self, index, child):
         # Handle negative indexes.  Note that if index < -len(self),
@@ -1200,7 +1216,7 @@ class AbstractParentedTree(Tree, metaclass=ABCMeta):
         # Set the child's parent, and update our child list.
         if isinstance(child, Tree):
             self._setparent(child, index)
-        super(AbstractParentedTree, self).insert(index, child)
+        super().insert(index, child)
 
     def pop(self, index=-1):
         if index < 0:
@@ -1209,7 +1225,7 @@ class AbstractParentedTree(Tree, metaclass=ABCMeta):
             raise IndexError("index out of range")
         if isinstance(self[index], Tree):
             self._delparent(self[index], index)
-        return super(AbstractParentedTree, self).pop(index)
+        return super().pop(index)
 
     # n.b.: like `list`, this is done by equality, not identity!
     # To remove a specific child, use del ptree[i].
@@ -1217,7 +1233,7 @@ class AbstractParentedTree(Tree, metaclass=ABCMeta):
         index = self.index(child)
         if isinstance(self[index], Tree):
             self._delparent(self[index], index)
-        super(AbstractParentedTree, self).remove(child)
+        super().remove(child)
 
     # We need to implement __getslice__ and friends, even though
     # they're deprecated, because otherwise list.__getslice__ will get
@@ -1258,7 +1274,7 @@ class ParentedTree(AbstractParentedTree):
     def __init__(self, node, children=None):
         self._parent = None
         """The parent of this Tree, or None if it has no parent."""
-        super(ParentedTree, self).__init__(node, children)
+        super().__init__(node, children)
         if children is None:
             # If children is None, the tree is read from node.
             # After parsing, the parent of the immediate children
@@ -1382,7 +1398,7 @@ class MultiParentedTree(AbstractParentedTree):
         """A list of this tree's parents.  This list should not
            contain duplicates, even if a parent contains this tree
            multiple times."""
-        super(MultiParentedTree, self).__init__(node, children)
+        super().__init__(node, children)
         if children is None:
             # If children is None, the tree is read from node.
             # After parsing, the parent(s) of the immediate children
@@ -1551,7 +1567,6 @@ class ImmutableMultiParentedTree(ImmutableTree, MultiParentedTree):
 ######################################################################
 
 
-
 class ProbabilisticTree(Tree, ProbabilisticMixIn):
     def __init__(self, node, children=None, **prob_kwargs):
         Tree.__init__(self, node, children)
@@ -1562,10 +1577,10 @@ class ProbabilisticTree(Tree, ProbabilisticMixIn):
         return ImmutableProbabilisticTree
 
     def __repr__(self):
-        return "%s (p=%r)" % (Tree.__repr__(self), self.prob())
+        return f"{Tree.__repr__(self)} (p={self.prob()!r})"
 
     def __str__(self):
-        return "%s (p=%.6g)" % (self.pformat(margin=60), self.prob())
+        return f"{self.pformat(margin=60)} (p={self.prob():.6g})"
 
     def copy(self, deep=False):
         if not deep:
@@ -1585,11 +1600,15 @@ class ProbabilisticTree(Tree, ProbabilisticMixIn):
             return val
 
     def __eq__(self, other):
-        return self.__class__ is other.__class__ and (
-            self._label,
-            list(self),
-            self.prob(),
-        ) == (other._label, list(other), other.prob())
+        return (
+            self.__class__ is other.__class__
+            and (
+                self._label,
+                list(self),
+                self.prob(),
+            )
+            == (other._label, list(other), other.prob())
+        )
 
     def __lt__(self, other):
         if not isinstance(other, Tree):
@@ -1604,7 +1623,6 @@ class ProbabilisticTree(Tree, ProbabilisticMixIn):
             return self.__class__.__name__ < other.__class__.__name__
 
 
-
 class ImmutableProbabilisticTree(ImmutableTree, ProbabilisticMixIn):
     def __init__(self, node, children=None, **prob_kwargs):
         ImmutableTree.__init__(self, node, children)
@@ -1616,10 +1634,10 @@ class ImmutableProbabilisticTree(ImmutableTree, ProbabilisticMixIn):
         return ImmutableProbabilisticTree
 
     def __repr__(self):
-        return "%s [%s]" % (Tree.__repr__(self), self.prob())
+        return f"{Tree.__repr__(self)} [{self.prob()}]"
 
     def __str__(self):
-        return "%s [%s]" % (self.pformat(margin=60), self.prob())
+        return f"{self.pformat(margin=60)} [{self.prob()}]"
 
     def copy(self, deep=False):
         if not deep:
@@ -1697,6 +1715,7 @@ def sinica_parse(s):
 
 #    return s
 
+
 ######################################################################
 ## Demonstration
 ######################################################################
@@ -1710,7 +1729,7 @@ def demo():
     and shows the results of calling several of their methods.
     """
 
-    from nltk import Tree, ProbabilisticTree
+    from nltk import ProbabilisticTree, Tree
 
     # Demonstrate tree parsing.
     s = "(S (NP (DT the) (NN cat)) (VP (VBD ate) (NP (DT a) (NN cookie))))"
