@@ -2,69 +2,74 @@
 #
 # Copyright (C) 2001-2021 NLTK Project
 # Author: Steven Bird <stevenbird1@gmail.com>
+#         Eric Kafe <kafe.eric@gmail.com> (acyclic closures)
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
 
-import sys
+import bisect
 import inspect
 import locale
-import re
-import types
-import textwrap
-import pydoc
-import bisect
 import os
-
-from itertools import islice, chain, combinations, tee
-from pprint import pprint
+import pydoc
+import re
+import sys
+import textwrap
+import types
+import warnings
 from collections import defaultdict, deque
-from sys import version_info
-
+from itertools import chain, combinations, islice, tee
+from pprint import pprint
 from urllib.request import (
-    build_opener,
-    install_opener,
-    getproxies,
-    ProxyHandler,
+    HTTPPasswordMgrWithDefaultRealm,
     ProxyBasicAuthHandler,
     ProxyDigestAuthHandler,
-    HTTPPasswordMgrWithDefaultRealm,
+    ProxyHandler,
+    build_opener,
+    getproxies,
+    install_opener,
 )
 
-from nltk.internals import slice_bounds, raise_unorderable_types
 from nltk.collections import *
-
+from nltk.internals import deprecated, raise_unorderable_types, slice_bounds
 
 ######################################################################
 # Short usage message
 ######################################################################
 
 
-def usage(obj, selfname="self"):
+@deprecated("Use help(obj) instead.")
+def usage(obj):
     str(obj)  # In case it's lazy, this will load it.
 
     if not isinstance(obj, type):
         obj = obj.__class__
 
-    print("%s supports the following operations:" % obj.__name__)
+    print(f"{obj.__name__} supports the following operations:")
     for (name, method) in sorted(pydoc.allmethods(obj).items()):
         if name.startswith("_"):
             continue
         if getattr(method, "__deprecated__", False):
             continue
 
-        getargspec = inspect.getfullargspec
-        args, varargs, varkw, defaults = getargspec(method)[:4]
-        if (
-            args
-            and args[0] == "self"
-            and (defaults is None or len(args) > len(defaults))
-        ):
-            args = args[1:]
-            name = "%s.%s" % (selfname, name)
-        argspec = inspect.formatargspec(args, varargs, varkw, defaults)
+        try:
+            sig = str(inspect.signature(method))
+        except ValueError as e:
+            # builtins sometimes don't support introspection
+            if "builtin" in str(e):
+                continue
+            else:
+                raise
+
+        args = sig.lstrip("(").rstrip(")").split(", ")
+        meth = inspect.getattr_static(obj, name)
+        if isinstance(meth, (classmethod, staticmethod)):
+            name = f"cls.{name}"
+        elif args and args[0] == "self":
+            name = f"self.{name}"
+            args.pop(0)
         print(
             textwrap.fill(
-                "%s%s" % (name, argspec),
+                f"{name}({', '.join(args)})",
                 initial_indent="  - ",
                 subsequent_indent=" " * (len(name) + 5),
             )
@@ -137,15 +142,6 @@ def tokenwrap(tokens, separator=" ", width=70):
     return "\n".join(textwrap.wrap(separator.join(tokens), width=width))
 
 
-##########################################################################
-# Python version
-##########################################################################
-
-
-def py25():
-    return version_info[0] == 2 and version_info[1] == 5
-
-
 ##########################################################################
 # Indexing
 ##########################################################################
@@ -191,7 +187,7 @@ def filestring(f):
     if hasattr(f, "read"):
         return f.read()
     elif isinstance(f, str):
-        with open(f, "r") as infile:
+        with open(f) as infile:
             return infile.read()
     else:
         raise ValueError("Must be called with a filename or file-like object")
@@ -222,11 +218,131 @@ def breadth_first(tree, children=iter, maxdepth=-1):
                 pass
 
 
+##########################################################################
+# Graph Drawing
+##########################################################################
+
+
+def edge_closure(tree, children=iter, maxdepth=-1, verbose=False):
+    """Yield the edges of a graph in breadth-first order,
+    discarding eventual cycles.
+    The first argument should be the start node;
+    children should be a function taking as argument a graph node
+    and returning an iterator of the node's children.
+
+    >>> from nltk.util import edge_closure
+    >>> print(list(edge_closure('A', lambda node:{'A':['B','C'], 'B':'C', 'C':'B'}[node])))
+    [('A', 'B'), ('A', 'C'), ('B', 'C'), ('C', 'B')]
+    """
+    traversed = set()
+    edges = set()
+    queue = deque([(tree, 0)])
+    while queue:
+        node, depth = queue.popleft()
+        traversed.add(node)
+        if depth != maxdepth:
+            try:
+                for child in children(node):
+                    if child not in traversed:
+                        queue.append((child, depth + 1))
+                    else:
+                        if verbose:
+                            warnings.warn(
+                                f"Discarded redundant search for {child} at depth {depth + 1}",
+                                stacklevel=2,
+                            )
+                    edge = (node, child)
+                    if edge not in edges:
+                        yield edge
+                        edges.add(edge)
+            except TypeError:
+                pass
+
+
+def edges2dot(edges, shapes=None, attr=None):
+    """
+    :param edges: the set (or list) of edges of a directed graph.
+
+    :return dot_string: a representation of 'edges' as a string in the DOT
+    graph language, which can be converted to an image by the 'dot' program
+    from the Graphviz package, or nltk.parse.dependencygraph.dot2img(dot_string).
+
+    :param shapes: dictionary of strings that trigger a specified shape.
+    :param attr: dictionary with global graph attributes
+
+    >>> import nltk
+    >>> from nltk.util import edges2dot
+    >>> print(edges2dot([('A', 'B'), ('A', 'C'), ('B', 'C'), ('C', 'B')]))
+    digraph G {
+    "A" -> "B";
+    "A" -> "C";
+    "B" -> "C";
+    "C" -> "B";
+    }
+
+    """
+    if not shapes:
+        shapes = dict()
+    if not attr:
+        attr = dict()
+
+    dot_string = "digraph G {\n"
+
+    for pair in attr.items():
+        dot_string += f"{pair[0]} = {pair[1]};\n"
+
+    for edge in edges:
+        for shape in shapes.items():
+            for node in range(2):
+                if shape[0] in repr(edge[node]):
+                    dot_string += f'"{edge[node]}" [shape = {shape[1]}];\n'
+        dot_string += f'"{edge[0]}" -> "{edge[1]}";\n'
+
+    dot_string += "}\n"
+    return dot_string
+
+
+def unweighted_minimum_spanning_digraph(tree, children=iter, shapes=None, attr=None):
+    """
+
+    Build a Minimum Spanning Tree (MST) of an unweighted graph,
+    by traversing the nodes of a tree in breadth-first order,
+    discarding eventual cycles.
+
+    Return a representation of this MST as a string in the DOT graph language,
+    which can be converted to an image by the 'dot' program from the Graphviz
+    package, or nltk.parse.dependencygraph.dot2img(dot_string).
+
+    The first argument should be the tree root;
+    children should be a function taking as argument a tree node
+    and returning an iterator of the node's children.
+
+    >>> import nltk
+    >>> wn=nltk.corpus.wordnet
+    >>> from nltk.util import unweighted_minimum_spanning_digraph as umsd
+    >>> print(umsd(wn.synset('bound.a.01'), lambda s:s.also_sees()))
+    digraph G {
+    "Synset('bound.a.01')" -> "Synset('unfree.a.02')";
+    "Synset('unfree.a.02')" -> "Synset('confined.a.02')";
+    "Synset('unfree.a.02')" -> "Synset('dependent.a.01')";
+    "Synset('unfree.a.02')" -> "Synset('restricted.a.01')";
+    "Synset('restricted.a.01')" -> "Synset('classified.a.02')";
+    }
+
+    """
+    return edges2dot(
+        edge_closure(
+            tree, lambda node: unweighted_minimum_spanning_dict(tree, children)[node]
+        ),
+        shapes,
+        attr,
+    )
+
+
 ##########################################################################
 # Breadth-First / Depth-first Searches with Cycle Detection
 ##########################################################################
 
-import warnings
 
 def acyclic_breadth_first(tree, children=iter, maxdepth=-1):
     """Traverse the nodes of a tree in breadth-first order,
@@ -248,7 +364,12 @@ def acyclic_breadth_first(tree, children=iter, maxdepth=-1):
                     if child not in traversed:
                         queue.append((child, depth + 1))
                     else:
-                        warnings.warn('Discarded redundant search for {0} at depth {1}'.format(child, depth + 1), stacklevel=2)
+                        warnings.warn(
+                            "Discarded redundant search for {} at depth {}".format(
+                                child, depth + 1
+                            ),
+                            stacklevel=2,
+                        )
             except TypeError:
                 pass
 
@@ -292,13 +413,22 @@ def acyclic_depth_first(tree, children=iter, depth=-1, cut_mark=None, traversed=
         try:
             for child in children(tree):
                 if child not in traversed:
-#                   Recurse with a common "traversed" set for all children:
+                    # Recurse with a common "traversed" set for all children:
                     traversed.add(child)
-                    out_tree += [acyclic_depth_first(child, children, depth - 1, cut_mark, traversed)]
+                    out_tree += [
+                        acyclic_depth_first(
+                            child, children, depth - 1, cut_mark, traversed
+                        )
+                    ]
                 else:
-                    warnings.warn('Discarded redundant search for {0} at depth {1}'.format(child, depth - 1), stacklevel=3)
+                    warnings.warn(
+                        "Discarded redundant search for {} at depth {}".format(
+                            child, depth - 1
+                        ),
+                        stacklevel=3,
+                    )
                     if cut_mark:
-                        out_tree += ['Cycle({0},{1},{2})'.format(child, depth - 1, cut_mark)]
+                        out_tree += [f"Cycle({child},{depth - 1},{cut_mark})"]
         except TypeError:
             pass
     elif cut_mark:
@@ -306,10 +436,12 @@ def acyclic_depth_first(tree, children=iter, depth=-1, cut_mark=None, traversed=
     return out_tree
 
 
-def acyclic_branches_depth_first(tree, children=iter, depth=-1, cut_mark=None, traversed=None):
+def acyclic_branches_depth_first(
+    tree, children=iter, depth=-1, cut_mark=None, traversed=None
+):
     """Traverse the nodes of a tree in depth-first order,
     discarding eventual cycles within the same branch,
-    but keep duplicate pathes in different branches.
+    but keep duplicate paths in different branches.
     Add cut_mark (when defined) if cycles were truncated.
 
     The first argument should be the tree root;
@@ -351,12 +483,25 @@ def acyclic_branches_depth_first(tree, children=iter, depth=-1, cut_mark=None, t
         try:
             for child in children(tree):
                 if child not in traversed:
-#                   Recurse with a different "traversed" set for each child:
-                    out_tree += [acyclic_branches_depth_first(child, children, depth - 1, cut_mark, traversed.union({child}))]
+                    # Recurse with a different "traversed" set for each child:
+                    out_tree += [
+                        acyclic_branches_depth_first(
+                            child,
+                            children,
+                            depth - 1,
+                            cut_mark,
+                            traversed.union({child}),
+                        )
+                    ]
                 else:
-                    warnings.warn('Discarded redundant search for {0} at depth {1}'.format(child, depth - 1), stacklevel=3)
+                    warnings.warn(
+                        "Discarded redundant search for {} at depth {}".format(
+                            child, depth - 1
+                        ),
+                        stacklevel=3,
+                    )
                     if cut_mark:
-                        out_tree += ['Cycle({0},{1},{2})'.format(child, depth - 1, cut_mark)]
+                        out_tree += [f"Cycle({child},{depth - 1},{cut_mark})"]
         except TypeError:
             pass
     elif cut_mark:
@@ -371,6 +516,48 @@ def acyclic_dic2tree(node, dic):
     return [node] + [acyclic_dic2tree(child, dic) for child in dic[node]]
 
 
+def unweighted_minimum_spanning_dict(tree, children=iter):
+    """
+    Output a dictionary representing a Minimum Spanning Tree (MST)
+    of an unweighted graph, by traversing the nodes of a tree in
+    breadth-first order, discarding eventual cycles.
+
+    The first argument should be the tree root;
+    children should be a function taking as argument a tree node
+    and returning an iterator of the node's children.
+
+    >>> import nltk
+    >>> from nltk.corpus import wordnet as wn
+    >>> from nltk.util import unweighted_minimum_spanning_dict as umsd
+    >>> from pprint import pprint
+    >>> pprint(umsd(wn.synset('bound.a.01'), lambda s:s.also_sees()))
+    {Synset('bound.a.01'): [Synset('unfree.a.02')],
+     Synset('classified.a.02'): [],
+     Synset('confined.a.02'): [],
+     Synset('dependent.a.01'): [],
+     Synset('restricted.a.01'): [Synset('classified.a.02')],
+     Synset('unfree.a.02'): [Synset('confined.a.02'),
+                             Synset('dependent.a.01'),
+                             Synset('restricted.a.01')]}
+
+    """
+    traversed = set()  # Empty set of traversed nodes
+    queue = deque([tree])  # Initialize queue
+    agenda = {tree}  # Set of all nodes ever queued
+    mstdic = {}  # Empty MST dictionary
+    while queue:
+        node = queue.popleft()  # Node is not yet in the MST dictionary,
+        mstdic[node] = []  # so add it with an empty list of children
+        if node not in traversed:  # Avoid cycles
+            traversed.add(node)
+            for child in children(node):
+                if child not in agenda:  # Queue nodes only once
+                    mstdic[node].append(child)  # Add child to the MST
+                    queue.append(child)  # Add child to queue
+                    agenda.add(child)
+    return mstdic
+
+
 def unweighted_minimum_spanning_tree(tree, children=iter):
     """
     Output a Minimum Spanning Tree (MST) of an unweighted graph,
@@ -392,21 +579,7 @@ def unweighted_minimum_spanning_tree(tree, children=iter):
       [Synset('dependent.a.01')],
       [Synset('restricted.a.01'), [Synset('classified.a.02')]]]]
     """
-    traversed = set()             # Empty set of traversed nodes
-    queue = deque([tree])         # Initialize queue
-    agenda = {tree}               # Set of all nodes ever queued
-    mstdic = {}                   # Empty MST dictionary
-    while queue:
-        node = queue.popleft()    # Node is not yet in the MST dictionary,
-        mstdic[node]=[]           # so add it with an empty list of children
-        if node not in traversed: # Avoid cycles
-            traversed.add(node)
-            for child in children(node):
-                if child not in agenda:            # Queue nodes only once
-                    mstdic[node].append(child)     # Add child to the MST
-                    queue.append(child)            # Add child to queue
-                    agenda.add(child)
-    return acyclic_dic2tree(tree, mstdic)
+    return acyclic_dic2tree(tree, unweighted_minimum_spanning_dict(tree, children))
 
 
 ##########################################################################
@@ -521,13 +694,13 @@ def transitive_closure(graph, reflexive=False):
     :rtype: dict(set)
     """
     if reflexive:
-        base_set = lambda k: set([k])
+        base_set = lambda k: {k}
     else:
         base_set = lambda k: set()
     # The graph U_i in the article:
-    agenda_graph = dict((k, graph[k].copy()) for k in graph)
+    agenda_graph = {k: graph[k].copy() for k in graph}
     # The graph M_i in the article:
-    closure_graph = dict((k, base_set(k)) for k in graph)
+    closure_graph = {k: base_set(k) for k in graph}
     for i in graph:
         agenda = agenda_graph[i]
         closure = closure_graph[i]
@@ -687,15 +860,15 @@ def ngrams(sequence, n, **kwargs):
     :rtype: sequence or iter
     """
     sequence = pad_sequence(sequence, n, **kwargs)
-    
+
     # Creates the sliding window, of n no. of items.
     # `iterables` is a tuple of iterables where each iterable is a window of n items.
     iterables = tee(sequence, n)
 
-    for i, sub_iterable in enumerate(iterables): # For each window,
-        for _ in range(i):                       # iterate through every order of ngrams
-            next(sub_iterable, None)             # generate the ngrams within the window.
-    return zip(*iterables) # Unpack and flattens the iterables.
+    for i, sub_iterable in enumerate(iterables):  # For each window,
+        for _ in range(i):  # iterate through every order of ngrams
+            next(sub_iterable, None)  # generate the ngrams within the window.
+    return zip(*iterables)  # Unpack and flattens the iterables.
 
 
 def bigrams(sequence, **kwargs):
@@ -714,8 +887,7 @@ def bigrams(sequence, **kwargs):
     :rtype: iter(tuple)
     """
 
-    for item in ngrams(sequence, 2, **kwargs):
-        yield item
+    yield from ngrams(sequence, 2, **kwargs)
 
 
 def trigrams(sequence, **kwargs):
@@ -734,11 +906,12 @@ def trigrams(sequence, **kwargs):
     :rtype: iter(tuple)
     """
 
-    for item in ngrams(sequence, 3, **kwargs):
-        yield item
+    yield from ngrams(sequence, 3, **kwargs)
 
 
-def everygrams(sequence, min_len=1, max_len=-1, pad_left=False, pad_right=False, **kwargs):
+def everygrams(
+    sequence, min_len=1, max_len=-1, pad_left=False, pad_right=False, **kwargs
+):
     """
     Returns all possible ngrams generated from a sequence of items, as an iterator.
 
@@ -785,7 +958,7 @@ def everygrams(sequence, min_len=1, max_len=-1, pad_left=False, pad_right=False,
 
     # Yield ngrams from sequence.
     while history:
-        for ngram_len in range(min_len, len(history)+1):
+        for ngram_len in range(min_len, len(history) + 1):
             yield tuple(history[:ngram_len])
 
         # Append element to history if sequence has more items.
@@ -797,7 +970,6 @@ def everygrams(sequence, min_len=1, max_len=-1, pad_left=False, pad_right=False,
         del history[0]
 
 
-
 def skipgrams(sequence, n, k, **kwargs):
     """
     Returns all possible skipgrams generated from a sequence of items, as an iterator.
@@ -946,7 +1118,7 @@ def set_proxy(proxy, user=None, password=""):
         opener.add_handler(ProxyBasicAuthHandler(password_manager))
         opener.add_handler(ProxyDigestAuthHandler(password_manager))
 
-    # Overide the existing url opener
+    # Override the existing url opener
     install_opener(opener)
 
 
@@ -1028,14 +1200,15 @@ def pairwise(iterable):
     next(b, None)
     return zip(a, b)
 
+
 ######################################################################
-# Parallization.
+# Parallelization.
 ######################################################################
 
 
 def parallelize_preprocess(func, iterator, processes, progress_bar=False):
-    from tqdm import tqdm
     from joblib import Parallel, delayed
+    from tqdm import tqdm
 
     iterator = tqdm(iterator) if progress_bar else iterator
     if processes <= 1:
